@@ -4,7 +4,7 @@ from math import floor, radians
 # from os import system
 from os.path import dirname, join
 from struct import unpack
-from sys import argv, exit
+from sys import exit
 
 from numpy import array, empty, float64, fromfile
 
@@ -80,6 +80,15 @@ def convert2coord_pairs(polygon_data):
     return coodinate_list
 
 
+def coord2shortcut(lng, lat):
+    return int(floor((lng + 180))), int(floor((90 - lat) * 2))
+
+
+def assert_valid_range(lng, lat):
+    if lng > 180.0 or lng < -180.0 or lat > 90.0 or lat < -90.0:
+        raise ValueError('The coordinates are out ouf bounds: (', lng, ',', lat, ')')
+
+
 class TimezoneFinder:
     """
     This class lets you quickly find the timezone of a point on earth.
@@ -90,7 +99,6 @@ class TimezoneFinder:
     """
 
     def __init__(self):
-
         # open all the files in binary reading mode
         # for more info on what is stored in which .bin file, please read the comments in file_converter.py
         self.poly_zone_ids = open(join(dirname(__file__), 'poly_zone_ids.bin'), 'rb')
@@ -113,9 +121,8 @@ class TimezoneFinder:
         # store for which polygons (how many) holes exits and the id of the first of those holes
         # since there are very few (+-22) it is feasible to keep them in the memory
         self.hole_registry = {}
-        i = 0
         # read the polygon ids for all the holes
-        for block in iter(lambda: self.hole_poly_ids.read(2), b''):
+        for i, block in enumerate(iter(lambda: self.hole_poly_ids.read(2), b'')):
             poly_id = unpack(b'<H', block)[0]
             try:
                 amount_of_holes, hole_id = self.hole_registry[poly_id]
@@ -126,7 +133,6 @@ class TimezoneFinder:
                 self.hole_registry.update({
                     poly_id: (1, i)
                 })
-            i += 1
 
     def __del__(self):
         self.poly_zone_ids.close()
@@ -160,11 +166,9 @@ class TimezoneFinder:
     def ids_of(self, iterable):
         id_array = empty(shape=len(iterable), dtype='<i1')
 
-        i = 0
-        for line_nr in iterable:
+        for i, line_nr in enumerate(iterable):
             self.poly_zone_ids.seek((2 * line_nr))
             id_array[i] = unpack(b'<H', self.poly_zone_ids.read(2))[0]
-            i += 1
 
         return id_array
 
@@ -181,8 +185,10 @@ class TimezoneFinder:
 
     def coords_of(self, line=0):
         # how many coordinates are stored in this polygon
-        self.poly_coord_amount.seek(2 * line)
-        nr_of_values = unpack(b'<H', self.poly_coord_amount.read(2))[0]
+        self.poly_coord_amount.seek(4 * line)
+        nr_of_values = unpack(b'<I', self.poly_coord_amount.read(4))[0]
+        if nr_of_values == 0:
+            raise ValueError
 
         self.poly_adr2data.seek(4 * line)
         self.poly_data.seek(unpack(b'<I', self.poly_adr2data.read(4))[0])
@@ -210,13 +216,12 @@ class TimezoneFinder:
 
     def get_polygon(self, polygon_nr, coords_as_pairs=False):
         list_of_converted_polygons = []
-
         if coords_as_pairs:
             conversion_method = convert2coord_pairs
         else:
             conversion_method = convert2coords
-
         list_of_converted_polygons.append(conversion_method(self.coords_of(line=polygon_nr)))
+
         for hole in self._holes_of_line(polygon_nr):
             list_of_converted_polygons.append(conversion_method(hole))
 
@@ -249,7 +254,6 @@ class TimezoneFinder:
         first_polygon_nr = unpack(b'<H', self.poly_nr2zone_id.read(2))[0]
         # read poly_nr of the first polygon of the next zone
         last_polygon_nr = unpack(b'<H', self.poly_nr2zone_id.read(2))[0]
-        print(first_polygon_nr, last_polygon_nr, range(first_polygon_nr, last_polygon_nr))
         poly_nrs = range(first_polygon_nr, last_polygon_nr)
         return [self.get_polygon(poly_nr, coords_as_pairs) for poly_nr in poly_nrs]
 
@@ -260,16 +264,13 @@ class TimezoneFinder:
         :return: (list of zone_ids, boolean: do all entries belong to the same zone)
         """
         zone_id_list = empty([nr_of_polygons], dtype='<u2', )
-        pointer_local = 0
-
         first_id = self.id_of(polygon_id_list[0])
         equal = True
-        for polygon_id in polygon_id_list:
+        for pointer_local, polygon_id in enumerate(polygon_id_list):
             zone_id = self.id_of(polygon_id)
             if zone_id != first_id:
                 equal = False
             zone_id_list[pointer_local] = zone_id
-            pointer_local += 1
 
         return zone_id_list, equal
 
@@ -298,17 +299,14 @@ class TimezoneFinder:
             return True
 
         zone_id_list = empty([nr_of_polygons], dtype='<u2', )
-        pointer_local = 0
         counted_zones = {}
-        for polygon_id in polygon_id_list:
+        for pointer_local, polygon_id in enumerate(polygon_id_list):
             zone_id = self.id_of(polygon_id)
             zone_id_list[pointer_local] = zone_id
-            pointer_local += 1
             try:
                 counted_zones[zone_id] += 1
             except KeyError:
                 counted_zones[zone_id] = 1
-        # print(counted_zones)
 
         if len(counted_zones) == 1:
             # there is only one zone. no sorting needed.
@@ -376,13 +374,11 @@ class TimezoneFinder:
             nr_points = len(coords[0])
             return distance_to_polygon(lng, lat, nr_points, coords)
 
-        if lng > 180.0 or lng < -180.0 or lat > 90.0 or lat < -90.0:
-            raise ValueError('The coordinates are out ouf bounds: (', lng, ',', lat, ')')
+        assert_valid_range(lng, lat)
 
         # transform point X into cartesian coordinates
         current_closest_id = None
-        central_x_shortcut = int(floor((lng + 180)))
-        central_y_shortcut = int(floor((90 - lat) * 2))
+        central_x_shortcut, central_y_shortcut = coord2shortcut(lng, lat)
 
         lng = radians(lng)
         lat = radians(lat)
@@ -431,22 +427,20 @@ class TimezoneFinder:
 
         distances = empty(polygons_in_list, dtype=float64)
         # [None for i in range(polygons_in_list)]
-        pointer = 0
 
         if force_evaluation:
-            for polygon_nr in possible_polygons:
+            for pointer, polygon_nr in enumerate(possible_polygons):
                 distance = routine(polygon_nr)
                 distances[pointer] = distance
                 if distance < min_distance:
                     min_distance = distance
                     current_closest_id = ids[pointer]
-                pointer += 1
 
         else:
+            pointer = 0
             # stores which polygons have been checked yet
             already_checked = [False] * polygons_in_list  # initialize array with False
             while pointer < polygons_in_list:
-
                 # only check a polygon when its id is not the closest a the moment and it has not been checked already!
                 if already_checked[pointer] or ids[pointer] == current_closest_id:
                     # go to the next polygon
@@ -482,15 +476,12 @@ class TimezoneFinder:
         :param lat: latitude in degree (90 to -90)
         :return: the timezone name of a matching polygon or None
         """
-        if lng > 180.0 or lng < -180.0 or lat > 90.0 or lat < -90.0:
-            raise ValueError('The coordinates are out ouf bounds: ( %f, %f, )' % (lng, lat))
-
+        assert_valid_range(lng, lat)
         # x = longitude  y = latitude  both converted to 8byte int
         x = coord2int(lng)
         y = coord2int(lat)
 
-        shortcut_id_x = int(floor((lng + 180)))
-        shortcut_id_y = int(floor((90 - lat) * 2))
+        shortcut_id_x, shortcut_id_y = coord2shortcut(lng, lat)
         self.shortcuts_unique_id.seek((720 * shortcut_id_x + 2 * shortcut_id_y))
         try:
             return timezone_names[unpack(b'<H', self.shortcuts_unique_id.read(2))[0]]
@@ -550,11 +541,8 @@ class TimezoneFinder:
         :return: the timezone name of the polygon the point is included in or None
         """
 
-        if lng > 180.0 or lng < -180.0 or lat > 90.0 or lat < -90.0:
-            raise ValueError('The coordinates are out ouf bounds: (', lng, ',', lat, ')')
-
-        shortcut_id_x = int(floor((lng + 180)))
-        shortcut_id_y = int(floor((90 - lat) * 2))
+        assert_valid_range(lng, lat)
+        shortcut_id_x, shortcut_id_y = coord2shortcut(lng, lat)
         possible_polygons = self.polygons_of_shortcut(shortcut_id_x, shortcut_id_y)
 
         # x = longitude  y = latitude  both converted to 8byte int
@@ -585,6 +573,8 @@ class TimezoneFinder:
 
 
 if __name__ == '__main__':
+    from sys import argv
+
     arguments = argv
     nr_arguments = len(arguments)
     if nr_arguments < 3:
